==> xcsoar-7.12.tar.xz: xcsoar-7.12/src/Engine/Task/ObservationZones/Boundary.hpp <==
/*
  Copyright_License {

  XCSoar Glide Computer - http://www.xcsoar.org/
  Copyright (C) 2000-2021 The XCSoar Project
  A detailed list of copyright holders can be found in the file "AUTHORS".

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
}
*/

#ifndef XCSOAR_OBSERVATION_ZONE_BOUNDARY_HPP
#define XCSOAR_OBSERVATION_ZONE_BOUNDARY_HPP

#include "Geo/GeoPoint.hpp"

#include <forward_list>

class OZBoundary : public std::forward_list<GeoPoint> {
public:
  /**
   * Generate boundary points for the arc described by the parameters.
   * This excludes the points at the start/end angle.
   *
   * The arc is generated in an increasing angle order - i.e. CW.
   *
   * @param center The origin of the radials - phi, lambda
   * @param radius The radius of the arc - meters.
   * @param start_radial The most CCW portion of the arc - radians.
   * @param end_radial The most CW portion of the arc - radians.
   */
  void GenerateArcExcluding(const GeoPoint &center, double radius,
                            Angle start_radial, Angle end_radial);
};

#endif

==> xcsoar-7.28.tar.xz: xcsoar-7.28/src/Engine/Task/ObservationZones/Boundary.hpp <==
/*
  Copyright_License {

  XCSoar Glide Computer - http://www.xcsoar.org/
  Copyright (C) 2000-2022 The XCSoar Project
  A detailed list of copyright holders can be found in the file "AUTHORS".

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
}
*/

#pragma once

#include "Geo/GeoPoint.hpp"

#include <forward_list>

class OZBoundary : public std::forward_list<GeoPoint> {
public:
  /**
   * Generate boundary points for the arc described by the parameters.
   * This excludes the points at the start/end angle.
   *
   * The arc is generated in an increasing angle order - i.e. CW.
   *
   * @param center The origin of the radials - phi, lambda
   * @param radius The radius of the arc - meters.
   * @param start_radial The most CCW portion of the arc - radians.
   * @param end_radial The most CW portion of the arc - radians.
   */
  void GenerateArcExcluding(const GeoPoint &center, double radius,
                            Angle start_radial, Angle end_radial);
};
